| plot.apc | R Documentation |
Plot apc object
## S3 method for class 'apc'
plot(
x,
quantiles = c(0.05, 0.5, 0.95),
convention = c("age", "period", "cohort", "none"),
combined = FALSE,
...
)
x |
apc object |
quantiles |
quantiles to plot. Default: |
convention |
display-layer gauge convention for the linear trend (drift)
in a full age-period-cohort model; one of |
combined |
logical. For heterogeneity models, if |
... |
Additional arguments will be ignored |
Plot of age, period and cohort effects from apc objects. If covariates have been used for period/cohort, a second plot with covariate, absolute effect and relative effect is created. Absolute effect is relative effect times covariate.
plot
## Not run:
data(apc)
model <- bamp(cases, population, age="rw1", period="rw1", cohort="rw1", periods_per_agegroup = 5)
plot(model)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.